@@ -75,8 +75,8 @@ class GQLQueriesManager(IGQLQueriesManager):
                     try:
                         if not await _eval(client_response):
                             continue
-                    except (aiohttp.client_exceptions.ContentTypeError, asyncio.exceptions.TimeoutError):
-                        self._logger.error('Response content unpacking failed.')
+                    except (aiohttp.client_exceptions.ContentTypeError, asyncio.TimeoutError):
+                        self._logger.warning('Response content unpacking failed.')
                         continue
 
                     yield heuristic, heuristic.__engine__
